
@echo off
@setlocal enabledelayedexpansion

set tiphome=%1
set tipadmin=%2
set tippass=%3
set arg4=%4
set ifix=tip2209_22011_PI12213
set ifix_file=PI12213.zip

echo.
echo ******************************************************************
echo     Tivoli Integrated Portal IFIX %ifix% Installation
echo ******************************************************************
echo.


if '%tiphome%' == '' (
  goto ERROR_USAGE
)

if '%tipadmin%' == '' (
  goto ERROR_USAGE
)

if '%tippass%' == '' (
  goto ERROR_USAGE
) 

if not '%arg4%' == '' (
  goto ERROR_USAGE
)

if not exist %tiphome% (
  goto ERROR_TIPHOME
)

set drive=%tiphome:~0,2%
if not '%drive:~1,1%' == ':' (
  rem handle quoted path
  set drive=%tiphome:~1,2%
)

if /I not '%~d0' == '%drive%' (
  rem This script must run on the same drive as TIP is installed...
  goto ERROR_DRIVE
)

echo Checking for a valid TIP 2.2.0.9 or TIP2.2.0.11 installation...
set props=%tiphome%\profiles\TIPProfile\installedApps\TIPCell\isc.ear\isclite.war\WEB-INF\config\isc.version.properties 
if not exist %props% (
 rem goto ERROR_TIPHOME
)
findstr "isc.version=2.2.0.9 isc.version=2.2.0.11" %props% 1>nul 2>&1
if not %ERRORLEVEL% == 0 (
  rem goto ERROR_TIPHOME
) 

echo Checking to see if the TIP server has been stopped...
%tiphome%\profiles\TIPProfile\bin\serverstatus.bat server1 -user '%tipadmin%' -password '%tippass%' | findstr ADMU0509I 1>nul 2>&1
if not %ERRORLEVEL% == 0 (
  goto ERROR_TIPSERVER 
)

echo Checking to see if this IFIX has already been installed...
if exist %tiphome%\properties\ifixes\%ifix% (
  goto ERROR_IFIX_INSTALLED
)

echo Backing up old files...
set file1=%tiphome%\profiles\TIPProfile\upgrade\lib\ext\tipcli.jar
echo    Copying %file1% to %file1%.%ifix%
copy %file1% %file1%.%ifix%
if not %ERRORLEVEL% == 0 (
  goto ERROR_BACKUP
)
set file2=%tiphome%\profiles\TIPProfile\installedApps\TIPCell\isc.ear\exportImport.war\WEB-INF\lib\tipcli.jar
echo    Copying %file2% to %file2%.%ifix%
copy %file2% %file2%.%ifix%
if not %ERRORLEVEL% == 0 (
  goto ERROR_BACKUP
)

echo Installing new files...
copy .\%ifix_file% %tiphome%
if not %ERRORLEVEL% == 0 (
  goto ERROR_INSTALL
)
pushd %tiphome%
%tiphome%\java\bin\jar xvf .\%ifix_file%
if not %ERRORLEVEL% == 0 (
  popd
  goto ERROR_INSTALL
)

echo Updating tipcli.jar...
%tiphome%\java\bin\jar uvf %file1% com\ibm\tivoli\tip\cli\*.class
if not %ERRORLEVEL% == 0 (
    rmdir /s /q %tiphome%\com 1>nul 2>&1
    popd
    goto ERROR_INSTALL
  )
%tiphome%\java\bin\jar uvf %file2% com\ibm\tivoli\tip\cli\*.class

  if not %ERRORLEVEL% == 0 (
    rmdir /s /q %tiphome%\com 1>nul 2>&1
    popd
    goto ERROR_INSTALL
  )
  
rmdir /s /q  %tiphome%\upgrade 1>nul 2>&1
rmdir /s /q  %tiphome%\com 1>nul 2>&1

del %tiphome%\%ifix_file% 1>nul 2>&1
popd

if not exist %tiphome%\properties\ifixes (
  mkdir %tiphome%\properties\ifixes
)

date /T > %tiphome%\properties\ifixes\%ifix%
time /T >> %tiphome%\properties\ifixes\%ifix%

goto SUCCESS

:ERROR_DRIVE
   echo. 
   echo Error: Please run this bat file on the same drive as TIP is installed.
   goto ERROR

:ERROR_INSTALL
   echo.
   echo Error: Installing new files failed.
   goto ERROR 

:ERROR_BACKUP
   echo.
   echo Error: Backing up old files failed. 
   goto ERROR

:ERROR_IFIX_INSTALLED
   echo.
   echo Error: IFIX %ifix% has already been installed.
   goto ERROR

:ERROR_TIPSERVER
   echo.
   echo Error: The TIP Server must be stopped before the IFIX can be installed.
   goto ERROR

:ERROR_TIPHOME
   echo.
   echo Error: '%tiphome%' is not a valid 2.2.0.9 or 2.2.0.11 TIP install location.
   echo Example: install_ifix.bat c:\IBM\tivoli\tipv2 tipadmin tippass
   goto ERROR
 
:ERROR_USAGE
   echo.
   echo Usage: install_ifix.bat TIP_HOME TIP_ADMIN TIP_ADMIN_PASSWORD
   echo Example: install_ifix.bat c:\ibm\tivoli\tipv2 tipadmin tippass

:ERROR
   echo.
   echo TIP IFIX install did not complete successfully.
   echo.
   exit /b 1

:SUCCESS
   echo.
   echo TIP IFIX install finished successfully.
   echo.
   echo.
   exit /b 0
